==> zenml_nightly-0.81.0.dev20250424-py3-none-any.whl: zenml/integrations/skypilot_kubernetes/__init__.py <==
#  Copyright (c) ZenML GmbH 2024. All Rights Reserved.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at:
#
#       https://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
#  or implied. See the License for the specific language governing
#  permissions and limitations under the License.
"""Initialization of the Skypilot Kubernetes integration for ZenML.

The Skypilot integration sub-module powers an alternative to the local
orchestrator for a remote orchestration of ZenML pipelines on VMs.
"""
from typing import List, Type

from zenml.integrations.constants import (
    SKYPILOT_KUBERNETES,
)
from zenml.integrations.integration import Integration
from zenml.stack import Flavor

SKYPILOT_KUBERNETES_ORCHESTRATOR_FLAVOR = "vm_kubernetes"


class SkypilotKubernetesIntegration(Integration):
    """Definition of Skypilot Kubernetes Integration for ZenML."""

    NAME = SKYPILOT_KUBERNETES
    # all 0.6.x versions of skypilot[kubernetes] are compatible
    REQUIREMENTS = ["skypilot[kubernetes]~=0.8.0"]
    APT_PACKAGES = ["openssh-client", "rsync"]

    @classmethod
    def flavors(cls) -> List[Type[Flavor]]:
        """Declare the stack component flavors for the Skypilot Kubernetes integration.

        Returns:
            List of stack component flavors for this integration.
        """
        from zenml.integrations.skypilot_kubernetes.flavors import (
            SkypilotKubernetesOrchestratorFlavor,
        )

        return [SkypilotKubernetesOrchestratorFlavor]

==> zenml_nightly-0.83.0.dev20250622-py3-none-any.whl: zenml/integrations/skypilot_kubernetes/__init__.py <==
#  Copyright (c) ZenML GmbH 2024. All Rights Reserved.
#
#  Licensed under the Apache License, Version 2.0 (the "License");
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at:
#
#       https://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS,
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
#  or implied. See the License for the specific language governing
#  permissions and limitations under the License.
"""Initialization of the Skypilot Kubernetes integration for ZenML.

The Skypilot integration sub-module powers an alternative to the local
orchestrator for a remote orchestration of ZenML pipelines on VMs.
"""
from typing import List, Type

from zenml.integrations.constants import (
    SKYPILOT_KUBERNETES,
)
from zenml.integrations.integration import Integration
from zenml.stack import Flavor

SKYPILOT_KUBERNETES_ORCHESTRATOR_FLAVOR = "vm_kubernetes"


class SkypilotKubernetesIntegration(Integration):
    """Definition of Skypilot Kubernetes Integration for ZenML."""

    NAME = SKYPILOT_KUBERNETES

    REQUIREMENTS = ["skypilot[kubernetes]==0.9.3"]
    APT_PACKAGES = ["openssh-client", "rsync"]

    @classmethod
    def flavors(cls) -> List[Type[Flavor]]:
        """Declare the stack component flavors for the Skypilot Kubernetes integration.

        Returns:
            List of stack component flavors for this integration.
        """
        from zenml.integrations.skypilot_kubernetes.flavors import (
            SkypilotKubernetesOrchestratorFlavor,
        )

        return [SkypilotKubernetesOrchestratorFlavor]
